<?php
/**
 * Related Products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/related.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce/Templates
 * @version     3.9.0
 */

if (!defined('ABSPATH')) {
    exit;
}

$product_related_enable = G5SHOP()->options()->get_option('product_related_enable');
if ($product_related_enable !== 'on') return;
$columns_gutter = absint(G5SHOP()->options()->get_option('product_related_columns_gutter'));
$columns_xl = absint(G5SHOP()->options()->get_option('product_related_columns_xl'));
$columns_lg = absint(G5SHOP()->options()->get_option('product_related_columns_lg'));
$columns_md = absint(G5SHOP()->options()->get_option('product_related_columns_md'));
$columns_sm = absint(G5SHOP()->options()->get_option('product_related_columns_sm'));
$columns = absint(G5SHOP()->options()->get_option('product_related_columns'));

$settings = array(
    'post_layout' => 'grid',
    //'item_skin' => 'skin-01',
    //'image_size' => 'woocommerce_thumbnail',
    //'image_ratio' => '',
    'columns_gutter' => $columns_gutter,
    'post_animation' => 'none',
    //'excerpt_enable' => false,
    //'category_enable' => false,
);

$slick = g5shop_get_slick_config(array(
	'arrows' => false,
	'dots' => true,
	'columns' => array(
		'xl' =>  $columns_xl,
		'lg' =>  $columns_lg,
		'md' =>  $columns_md,
		'sm' =>  $columns_sm,
		''   =>  $columns,
	)
));
$settings['slick'] = $slick;

$settings = apply_filters('g5shop_single_related_layout_setting',$settings);


G5SHOP()->listing()->set_layout_settings($settings);

$wrapper_classes = [
	'related',
	'products'
];
$custom_css_class = G5SHOP()->options()->get_option('single_product_related_custom_css_class');
if (!empty($custom_css_class)) {
	$wrapper_classes[] = $custom_css_class;
}
$wrapper_class = join(' ', apply_filters('g5shop_single_product_related_wrapper_classes',$wrapper_classes) );

if ($related_products) : ?>

    <div class="<?php echo esc_attr($wrapper_class)?>">

	    <?php
	    $heading = apply_filters( 'woocommerce_product_related_products_heading', __( 'Related products', 'woocommerce' ) );

	    if ( $heading ) :
		    ?>
		    <h2><?php echo esc_html( $heading ); ?></h2>
	    <?php endif; ?>

        <?php woocommerce_product_loop_start(); ?>

        <?php foreach ($related_products as $related_product) : ?>

            <?php
            $post_object = get_post($related_product->get_id());

            setup_postdata($GLOBALS['post'] =& $post_object);

            wc_get_template_part('content', 'product'); ?>

        <?php endforeach; ?>

        <?php woocommerce_product_loop_end(); ?>

    </div>

<?php endif;

wp_reset_postdata();

G5SHOP()->listing()->unset_layout_settings();